
*This do file builds the national data set

*******************************************************************************
*1. National Tax Change data 
*******************************************************************************

use "$dtadir_taxsim/tax_changes_national.dta", clear

tempfile natl_data
sort year
save `natl_data', replace

*******************************************************************************
*2. National Employment Data (CPS collapse)
*******************************************************************************

use "$dtadir_cps/natl_yr-hrs_lfp_wages_fullsample.dta", clear
keep year employed lfp hours parttime_emp epop hours_atleast48wks

label var employed "National Employment Rate, CPS"
label var lfp "National LFP, CPS"
label var hours "National hours, CPS"
label var parttime_emp "Part time employment, CPS"
label var epop "Employees to Population Ratio (differs from employed), CPS"
label var hours_atleast48wks "National hours (at least 48 weeeks worked), CPS"

tempfile natl_cps
sort year
save `natl_cps', replace

*******************************************************************************
*3. Consumption & Investment Data (NIPA)
*******************************************************************************
use "$dtadir_nipa/NIPA.dta", clear
ds year, not
foreach var in `r(varlist)' {
	rename `var' `var'_NIPA
}

tempfile data_nipa
save `data_nipa', replace

*******************************************************************************
*4. HOURS SERIES (OECD)
*******************************************************************************

use "$dtadir_oecd/natl_hours_series_oecd.dta", clear
sort year

tempfile data_oecd
save `data_oecd', replace


*******************************************************************************
*5. EMPLOYMENT SERIES (BLS)
*******************************************************************************

use "$dtadir_bls/National Employment by Year.dta", clear
sort year

replace employment = employment*1000 /* scale */
rename employment emp 
g ln_emp = ln(emp)

label var emp "Employment, BLS"
label var ln_emp "Log Employment, BLS"


tempfile data_bls
save `data_bls', replace


*******************************************************************************
*6. NATIONAL BEA SERIES (SA4); PERSONAL INCOME, NET EARNINGS, ETC.
*******************************************************************************

use "$dtadir_bea/natl_persinc_earnings.dta", clear
sort year

tempfile data_natl_bea
save `data_natl_bea', replace


*******************************************************************************
*7. NATIONAL MECHANICAL POLICY CHANGES
*******************************************************************************

*AFDC
use "$dtadir_controls/natl_afdc.dta", clear
tempfile data_natl_afdc
save `data_natl_afdc', replace

*TANF
use "$dtadir_controls/natl_tanf.dta", clear
tempfile data_natl_tanf
save `data_natl_tanf', replace

*SSI
use "$dtadir_controls/natl_ssi.dta", clear
tempfile data_natl_ssi
save `data_natl_ssi', replace

*SNAP
use "$dtadir_controls/natl_snap.dta", clear
tempfile data_natl_snap
save `data_natl_snap', replace

*Medicaid
use "$dtadir_controls/natl_medicaid.dta", clear
tempfile data_natl_medicaid
save `data_natl_medicaid', replace



*******************************************************************************
*8. MERGE NATIONAL DATASETS	AND FINISH
*******************************************************************************

/* Draw national tax change set and merge supplementary information */
use `natl_data', clear

/* CPS */

merge 1:1 year using `natl_cps'
tab _merge
table year, c(m _merge)
drop _merge

/* NIPA datasets */

merge 1:1 year using `data_nipa'
tab _merge
table year, c(m _merge)
drop _merge

/* OECD */

merge 1:1 year using `data_oecd'
tab _merge
table year, c(m _merge)
drop _merge

/* BLS */

merge 1:1 year using `data_bls'
tab _merge
table year, c(m _merge)
drop _merge

/* BEA (Personal Income, etc.) */

merge 1:1 year using `data_natl_bea'
tab _merge
table year, c(m _merge)
drop _merge


/* Mechanical Policy Controls */

merge 1:1 year using `data_natl_afdc'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 year using `data_natl_tanf'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 year using `data_natl_ssi'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 year using `data_natl_snap'
tab _merge
table year, c(m _merge)
drop _merge

merge 1:1 year using `data_natl_medicaid'
tab _merge
table year, c(m _merge)
drop _merge

*Restriction
sort year
keep if year >= 1950 & year <= 2007

*Generate afdc + tanf control (follows state analogously)
g afdc_tanf_chg1 = afdc_chg1
replace afdc_tanf_chg1 = tanf_chg1 if missing(afdc_chg1)

*Add real scalar (cpi)
real_usd, yr(2014)

*Scale BEA Variables (that are utilized)
g net_earnings_residence2014 = net_earnings_residence*cpi_scale_factor


*******************************************************************************
*9. Output
*******************************************************************************

save "$dtadir_final/analysis_natl_tcfw.dta", replace
