*This file cleans state analysis data:
	*Scales appropriate variables (or converts to real terms)
	*Adds log-versions of some variables
	*Adds cyclicality variables
	*Adds policy controls
	*Basic sample restriction

/*****************/
/*** Draw data ***/
/*****************/

use "$dtadir_final/analysis_st_tcfw_unclean.dta", replace

*Add real scalar (cpi)
real_usd, yr(2014)

/***********************************************/
/*** SCALE VARIABLES (THAT SHOULD BE SCALED) ***/
/***********************************************/

***Basic scalars and building remaining basic vars (i.e. GDP ($M) -> GDP, etc.)
replace gsp = gsp*1000000
g gsp_per_capita = gsp/(pop_census)
g govtrans_per_capita = govtrans/pop_census /* **CHECK THIS** */
g totalfedigrevenue_pc = totalfedigrevenue/pop_census


***2014 dollar vars (utilizing cpi_scale_factor from FRED)
g gsp2014 = gsp*cpi_scale_factor
g gsp_per_capita2014 = gsp_per_capita*cpi_scale_factor
g wage2014 = wage*cpi_scale_factor
g wage_comp_cons2014 = wage_comp_cons*cpi_scale_factor
g wage_CBP2014 = wage_CBP*cpi_scale_factor
g govtrans_per_capita2014 = govtrans_per_capita*cpi_scale_factor
g totalfedigrevenue_pc2014 = totalfedigrevenue_pc*cpi_scale_factor
g payroll2014 = payroll_CBP*cpi_scale_factor
g net_earnings_residence2014 = net_earnings_residence*cpi_scale_factor
g inctot2014 = inctot*cpi_scale_factor
g incdivid2014 = incdivid*cpi_scale_factor
g incrent2014 = incrent*cpi_scale_factor
g incint2014 = incint*cpi_scale_factor


***"Real Series" Variables
g real_gsp = gsp2014/ACCRA_state_cpi
g real_gsp_hpi = gsp/cpi_final_hpi
g real_payroll = payroll2014/ACCRA_state_cpi
g real_payroll_hpi = payroll_CBP/cpi_final_hpi
g real_wage = wage2014/ACCRA_state_cpi
g real_wage_cpi = wage/cpi_final
g real_wage_hpi = wage/cpi_final_hpi
g real_wage_priceBLS = wage/priceBLS
g real_wage_comp_cons = wage_comp_cons2014/ACCRA_state_cpi
g real_wage_comp_cons_hpi = wage_comp_cons/cpi_final_hpi


***Logs (and remaining constructions)
g ln_gsp2014 = ln(gsp2014)
g ln_real_gsp = ln(real_gsp)
g ln_real_gsp_hpi = ln(real_gsp_hpi) 
g ln_wage2014 = ln(wage2014)
g ln_wage_comp_cons2014 = ln(wage_comp_cons2014)
g ln_govtrans_per_capita2014=ln(govtrans_per_capita2014)
g ln_gsp_per_capita2014 = ln(gsp_per_capita2014)
g ln_totalfedigrevenue_pc2014 = ln(totalfedigrevenue_pc2014)
g ln_payroll = ln(payroll_CBP)
g ln_payroll2014 = ln(payroll2014)
g ln_real_payroll = ln(real_payroll)
g ln_real_payroll_hpi = ln(payroll2014/cpi_final_hpi)
g ln_wage_CBP2014 = ln(wage_CBP2014)
g ln_emp_CBP = ln(emp_CBP)
g ln_real_wage = ln(real_wage)
g ln_real_wage_cpi = ln(real_wage_cpi)
g ln_real_wage_hpi = ln(real_wage_hpi)
g ln_real_wage_priceBLS = ln(real_wage_priceBLS)
g ln_net_earnings_residence = ln(net_earnings_residence)
g ln_net_earnings_residence2014 = ln(net_earnings_residence2014)
g ln_cpi_final = ln(cpi_final)
g ln_cpi_final_hpi = ln(cpi_final_hpi)
g ln_real_net_earnings = ln_net_earnings_residence2014 - ln(ACCRA_state_cpi)
g ln_real_net_earnings_hpi = ln_net_earnings_residence2014 - ln(cpi_final_hpi)
g ln_inctot2014 = ln(inctot2014)
g ln_incdivid2014 = ln(incdivid2014)
g ln_incrent2014 = ln(incrent2014)
g ln_incint2014 = ln(incint2014)
g ln_real_wage_comp_cons = ln(real_wage_comp_cons)
g ln_real_wage_comp_cons_hpi = ln(real_wage_comp_cons_hpi)
g ln_ACCRA_state_cpi = ln(ACCRA_state_cpi)
g ln_priceBLS = ln(priceBLS)
g ln_hpi = ln(hpi)
g ln_persinc = ln(persinc)
g ln_dividends_interest_rent = ln(dividends_interest_rent)
g ln_personal_transfer_income = ln(personal_transfer_income)
	

***Resolving demographic split variables

*Scaled Total Income for demographics
g inctot2014_skill0 = inctot_skill0*cpi_scale_factor
g inctot2014_skill1 = inctot_skill1*cpi_scale_factor
g inctot2014_age1 = inctot_age1*cpi_scale_factor
g inctot2014_age2 = inctot_age2*cpi_scale_factor
g inctot2014_men_age1 = inctot_men_age1*cpi_scale_factor
g inctot2014_men_age2 = inctot_men_age2*cpi_scale_factor
g inctot2014_women_age1 = inctot_women_age1*cpi_scale_factor
g inctot2014_women_age2 = inctot_women_age2*cpi_scale_factor
g inctot2014_age_skill1 = inctot_age_skill1*cpi_scale_factor
g inctot2014_age_skill2 = inctot_age_skill2*cpi_scale_factor
g inctot2014_age_unskill1 = inctot_age_unskill1*cpi_scale_factor
g inctot2014_age_unskill2 = inctot_age_unskill2*cpi_scale_factor
g inctot2014_sex0 = inctot_sex0*cpi_scale_factor
g inctot2014_sex1 = inctot_sex1*cpi_scale_factor
g inctot2014_white0 = inctot_white0*cpi_scale_factor
g inctot2014_white1 = inctot_white1*cpi_scale_factor

*Scaled wage for demographic splits
g wage2014_skill0 = wage_skill0*cpi_scale_factor
g wage2014_skill1 = wage_skill1*cpi_scale_factor
g wage2014_age1 = wage_age1*cpi_scale_factor
g wage2014_age2 = wage_age2*cpi_scale_factor
g wage2014_men_age1 = wage_men_age1*cpi_scale_factor
g wage2014_men_age2 = wage_men_age2*cpi_scale_factor
g wage2014_women_age1 = wage_women_age1*cpi_scale_factor
g wage2014_women_age2 = wage_women_age2*cpi_scale_factor
g wage2014_age_skill1 = wage_age_skill1*cpi_scale_factor
g wage2014_age_skill2 = wage_age_skill2*cpi_scale_factor
g wage2014_age_unskill1 = wage_age_unskill1*cpi_scale_factor
g wage2014_age_unskill2 = wage_age_unskill2*cpi_scale_factor
g wage2014_sex0 = wage_sex0*cpi_scale_factor
g wage2014_sex1 = wage_sex1*cpi_scale_factor
g wage2014_white0 = wage_white0*cpi_scale_factor
g wage2014_white1 = wage_white1*cpi_scale_factor

*Real Wage (ACCRA) for demographic splits
g real_wage_skill0 = wage2014_skill0/ACCRA_state_cpi
g real_wage_skill1 = wage2014_skill1/ACCRA_state_cpi
g real_wage_age1 = wage2014_age1/ACCRA_state_cpi
g real_wage_age2 = wage2014_age2/ACCRA_state_cpi
g real_wage_men_age1 = wage2014_men_age1/ACCRA_state_cpi
g real_wage_men_age2 = wage2014_men_age2/ACCRA_state_cpi
g real_wage_women_age1 = wage2014_women_age1/ACCRA_state_cpi
g real_wage_women_age2 = wage2014_women_age2/ACCRA_state_cpi
g real_wage_age_skill1 = wage2014_age_skill1/ACCRA_state_cpi
g real_wage_age_skill2 = wage2014_age_skill2/ACCRA_state_cpi
g real_wage_age_unskill1 = wage2014_age_unskill1/ACCRA_state_cpi
g real_wage_age_unskill2 = wage2014_age_unskill2/ACCRA_state_cpi
g real_wage_sex0 = wage2014_sex0/ACCRA_state_cpi
g real_wage_sex1 = wage2014_sex1/ACCRA_state_cpi
g real_wage_white0 = wage2014_white0/ACCRA_state_cpi
g real_wage_white1 = wage2014_white1/ACCRA_state_cpi


*Logs for demographic split wages, hours (and restricted hours), total income, real wages (ACCRA)
ds wage2014_* inctot2014_* hours* real_wage_*
foreach var in `r(varlist)' {
	capture confirm variable ln_`var'
	if _rc { /* Check if log of variable exists (by naming convention); if not, then generate its log */
		g ln_`var' = ln(`var')
	}
}


*Generating #Employed for demographic splits (using CPS "counter" (weights) and emp (rate) post-collapse)
*Each "counter_" var has an additional substring component; for example counter_skill0 is the population in our sample that is indexed "skill0"
ds counter_*
foreach var in `r(varlist)' {
	g ratio_`var' = `var'/counter /* Ratio of "employed" belonging to demographic split */
	local tempstring = subinstr("`var'", "counter_", "", .) /* substring that excludes "counter_" */
	g emp_`tempstring' = employed_`tempstring'*(counter*ratio_`var')
	g ln_emp_`tempstring' = ln(emp_`tempstring')
	drop ratio_`var'
}

/*************************/
/*** State Cyclicality ***/
**************************/

/* SD of GSPPC */

preserve

tsset fips year
sort fips year

keep if year>=1963 &  year<1980

egen stdev_gsppc2014=sd(gsp_per_capita2014), by(fips_state)

keep fips_state stdev_*
duplicates drop
tempfile data_cyclicality
sort fips_state
save `data_cyclicality'

restore

*Re-merge
merge m:1 fips_state using `data_cyclicality'
tab _merge
table year, c(m _merge)
drop if fips_state==11
drop if _merge    ==2
drop _merge

*Generate cyclicality using sd of gsppc
xtile cyclicality = stdev_gsppc2014, nq(10)
egen yearXcyclicality=group(year cyclicality)


/* Beta-differencing */

preserve

*National GSPPC
bysort year: egen natl_gsp = total(gsp) /* Update 1/27/17 */
bysort year: egen natl_pop = total(pop_census)
g natl_gsp_per_capita = natl_gsp/natl_pop
g natl_gsp_per_capita2014 = natl_gsp_per_capita*cpi_scale_factor /* Scale */
drop natl_gsp natl_pop natl_gsp_per_capita


*Logs
g ln_natl_gsp_per_capita2014 = ln(natl_gsp_per_capita2014)

*Change
sort fips_state year
tsset fips_state year

g delta_gsp_per_capita2014 = ln_gsp_per_capita2014 - L1.ln_gsp_per_capita2014
g delta_natl_gsp_per_capita2014 = ln_natl_gsp_per_capita2014 - L1.ln_natl_gsp_per_capita2014

*Main regression by state to establish beta coefficients
g beta_coef = .
g se_coef = .
g beta_coef2 = .
g se_coef2 = .
qui levelsof fips_state, local(levels)
foreach state in `levels' {
	*Full period
	reg delta_gsp_per_capita2014 delta_natl_gsp_per_capita2014 if fips_state == `state'
	replace beta_coef = _b[delta_natl_gsp_per_capita2014] if fips_state == `state'
	replace se_coef = _se[delta_natl_gsp_per_capita2014] if fips_state == `state'
	
	*Pre-period
	reg delta_gsp_per_capita2014 delta_natl_gsp_per_capita2014 if fips_state == `state' & year < 1980
	replace beta_coef2 = _b[delta_natl_gsp_per_capita2014] if fips_state == `state'
	replace se_coef2 = _se[delta_natl_gsp_per_capita2014] if fips_state == `state'
}

*Baseline cyclicality control
xtile cyclical_beta = beta_coef, nq(5)
egen FX_beta_diff = group(cyclical_beta year)

*Beta-diff with 10 bins on full period
xtile cyclical_beta_alt1 = beta_coef, nq(10)
egen FX_beta_diff_alt1 = group(cyclical_beta_alt1 year)
*Beta-diff with 5 bins on pre-period
xtile cyclical_beta_alt2 = beta_coef2, nq(5)
egen FX_beta_diff_alt2 = group(cyclical_beta_alt2 year)


*Oil prices and interest rates interacted with state dummies (still in preservation)

egen st=group(fips)
tab st, gen(statedum)

forv i = 1/50 {
	g oil_cross`i' = priceWTI*statedum`i'
	g irate_cross`i' = irate_real*statedum`i'
}

sort fips_state year
tsset fips_state year

*Tempfile and re-merge
keep fips_state year FX_beta_diff* oil_cross* irate_cross*

tempfile data_cyc
save `data_cyc', replace

restore

*Re-merge
merge 1:1 fips_state year using `data_cyc'
assert _merge != 2 /* Don't want any from using only, which should already be the case */
drop _merge


/***********************/
/*** Policy controls ***/
************************/

*Create state dummies again (were dropped above in restricted sample)
egen st=group(fips)
tab st, gen(statedum)

*GDP proxy (sum of GSP)
bysort year: egen natl_gsp = total(gsp)

*Note that controls 1-3 are created in build file already

*4) Social Security: OASDI payments by state divided by ngsp
g ssec_cont = oasdi_ben/gsp /* Note: both nominal, so no need to adjust */
label var ssec_cont "OASDI payments by state divided by ngsp"

*5) COLA: Interact COLA with state dummies (like oil prices were done)
forv i = 1/50 {
	g cola_cross`i' = max_individual_own*statedum`i'
	label var cola_cross`i' "COLA interacted with state dummy `i'"
}

*6) SSI: federal average annual SSI payment * recipients by state divided by GSP (SUPPLEMENTAL SECURITY INCOME)
g ssi_cont = (avg_fedadm*12*rec_ssi)/gsp
label var ssi_cont "Federal average annual ssi payment * recipients by state divided by gsp"

*7) SNAP 1: nominal spending for benefits divided by gdp (proxy) interacted with state dummies
g snap_cont1 = exp_ben/natl_gsp
forv i = 1/50 {
	g snap_cont1_cross`i' = snap_cont1*statedum`i'
	label var snap_cont1_cross`i' "nominal spending for benefits divided by gdp interacted with state dummy `i'"
}

*8) SNAP 2: max allotment * lagged recipients by state divided by gsp (state)
sort fips_state year
g snap_cont2 = (max_48DC4*L3.rec_snap)/gsp /* Changed to 3 years lagged for number of recipients */
label var snap_cont2 "Max SNAP allotment * lagged recipients by state divided by gsp"

*9) SNAP 3: average (***monthly***) benefit per household * recipients by state divided by gsp (state)
g snap_cont3 = (avg_benefit*rec_snap)/gsp
label var snap_cont3 "Average SNAP benefit per household * recipients by state divided by gsp"

*10) Fed Poverty Interaction: Interacting FPL with state indicators; currently using family size of 4 (2 adults, 2 children) and iteracting with state
forv i = 1/50 {
	g FPL_cont_cross`i' = FPL_fam4*statedum`i'
	label var FPL_cont_cross`i' "Interact state dummy `i' with FPL for family of size 4"
}

*11) Medicaid 1: FMAP control
g medicaid_cont1 = fmap
label var medicaid_cont1 "FMAP"

*12) Medicaid 2: Average expenditure per beneficiary * recipients divided by gsp (state)
g medicaid_cont2 = medicaid_pay/gsp
label var medicaid_cont2 "Total Medicaid Vendor Payments divided by GSP"

*13) Medicare: Medicare part B standard monthly premium * lagged recipients by state divided by gsp (state)
sort fips_state year
g medicare_cont = (partB_std_prem*L3.en_medicare)/gsp
label var medicare_cont "Medicare premium * lagged recipients by state divided by gsp"

*14) AFDC + TANF 1: average payment per family * recipients by state divided by gsp (state)
g tanf_cont1 = (weighted_avg_tanf*rec_tanf)/gsp
g afdc_cont1 = (avg_afdc*rec_afdc)/gsp

g afdc_tanf_cont1 = afdc_cont1 if year < 1997
replace afdc_tanf_cont1 = tanf_cont1 if year >= 1997
label var afdc_tanf_cont1 "Average payment per family * recipients by state divided by gsp"

*15) AFDC + TANF 2: max benefit * lagged recipients by state divided by gsp (state)
sort fips_state year
g afdc_tanf_comb = max_ben_2ch_afdc
replace afdc_tanf_comb = benefit_fam3 if missing(max_ben_2ch_afdc)
g afdc_tanf_rec_comb = rec_afdc
replace afdc_tanf_rec_comb = rec_tanf if missing(rec_afdc)

g afdc_tanf_cont2 = (afdc_tanf_comb*L3.afdc_tanf_rec_comb)/gsp
label var afdc_tanf_cont2 "Max benefit * lagged recipients by state divided by gsp"


****Sum of mechanical changes (and combine mechanical changes in afdc & tanf into 1)
g afdc_tanf_chg1 = afdc_chg1
replace afdc_tanf_chg1 = tanf_chg1 if missing(afdc_chg1)

g mech_chg1 = afdc_chg1 + tanf_chg1 + ssi_chg1 + snap_chg1 + medaid_chg1
g mech_chg2 = afdc_chg2 + tanf_chg2 + ssi_chg2 + snap_chg2 + medaid_chg2


/********************/
/*** State trends ***/
/********************/

quietly for num 1/50: replace statedumX = statedumX*year


/******************************/
/*** Restriction and output ***/
/******************************/


keep if year>=1977 
tsset fips_state year
sort year fips_state
save "$dtadir_final/analysis_st_tcfw.dta", replace
